# Notify Service PHP Client

## Installation

In your shell of choice, execute:

`composer install myriad/notify-client-php`

## Configuration

Set the `NOTIFICATIONS_TOKEN` environmental variable and specify any channels and subscriptions you wish to support
in your config. Then pass those values into the constructor:

```php
$client = new Myriad\NotifyClient\Client(new Myriad\NotifyClient\Config($token, true, $channels, $subscriptions), new HttpClient);
```

HttpClient must implement `Myriad\NotifyClient\HttpInterface`.

## Usage

The main entrypoint for the SDK is the Client:

```php
$client = new Myriad\NotifyClient\Client(new Myriad\NotifyClient\Config($token), new HttpClient);
```

To construct a notification, you may use a NotificationBuilder:

```php
$notification = NotificationBuilder::create()
    ->title('Message title')
    ->summary('Message summary')
    ->filter(FilterBuilder::create()->forSubscriptions('weather_warning');
```

The filter restricts the set of registrants that receive the message. `FilterBuilder` can be used to construct many common queries.

To send the notification:
```
$client->createNotification($notification);
```

The `FilterBuilder` may also be used to query notifications and notification groups:

```php
$client->queryNotifications(FilterBuilder::create()->toUids($array_of_uids));
```

If you need to write a fancier query than what the `FilterBuilder` can handle, you can use `FilterBuilder::raw` to construct queries using MongoDB's query syntax:

```php
$filter = FilterBuilder::raw([ 'scheduledAt' => [ '$gte' => Carbon::now()->toRfc3339String() ] ]);
$client->queryNotifications($filter);
```
